@@ -44,5 +44,11 @@ ATTR_DEVICE_LOCK_V2 = "LockV2"
 ATTR_DEVICE_SOIL_TH_SENSOR = "SoilThcSensor"
 ATTR_DEVICE_SPRINKLER = "Sprinkler"
 ATTR_DEVICE_SPRINKLER_V2 = "SprinklerV2"
+ATTR_DEVICE_SMOKE_ALARM = "SmokeAlarm"
 
 UNIT_NOT_RECOGNIZED_TEMPLATE: Final = "{} is not a recognized {} unit."
+
+
+DEVICE_LEAK_STOP_MODELS = ["YS5009-UC", "YS5009-EC", "YS5029-UC", "YS5029-EC"]
+
+DEVICE_MODELS_SUPPORT_MODE_SWITCHING = DEVICE_LEAK_STOP_MODELS
